@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from django.utils import six
 from django.conf import settings
 from django.core.urlresolvers import reverse, resolve
 from django.shortcuts import redirect
@@ -129,7 +131,6 @@ class BetaMiddleware(object):
             request.session['hunger_in_beta'] = True
             return
 
-
         if not cookie_code:
             if not invitations:
                 invitation = Invitation(user=request.user)
@@ -139,20 +140,17 @@ class BetaMiddleware(object):
         # No invitation, all we have is this cookie code
         try:
             code = InvitationCode.objects.get(code=cookie_code,
-                num_invites__gt=0)
+                                              num_invites__gt=0)
         except InvitationCode.DoesNotExist:
             request._hunger_delete_cookie = True
             return redirect(reverse('hunger-invalid', args=(cookie_code,)))
 
         right_now = now()
         if code.private:
-            # If we got here, we're trying to fix up a previous private
-            # invitation to the correct user/email.
-            invitation = Invitation.objects.filter(code=code)[0]
-            invitation.user = request.user
-            invitation.invited = right_now
-            invitation.used = right_now
-            code.num_invites = 0
+            # User is trying to use a valid private code, but has no
+            # authority to use it (neither via username nor email)
+            request._hunger_delete_cookie = True
+            return redirect(reverse('hunger-invalid', args=(cookie_code,)))
         else:
             invitation = Invitation(user=request.user,
                                     code=code,
@@ -165,7 +163,11 @@ class BetaMiddleware(object):
 
     def process_response(self, request, response):
         if getattr(request, '_hunger_delete_cookie', False):
-            response.delete_cookie('hunger_code')
+            if six.PY2:
+                code = u'hunger_code'.encode('utf-8')
+            elif six.PY3:
+                code = 'hunger_code'
+            response.delete_cookie(code)
         return response
 
     @staticmethod
