@@ -1,11 +1,9 @@
-from django.core.urlresolvers import reverse_lazy
 from django.shortcuts import redirect
 from hunger.models import InvitationCode
 from hunger.forms import InviteSendForm
 from hunger.utils import setting, now
 from django.views.generic.base import TemplateView
 from django.views.generic.edit import FormView
-from django.contrib.auth.decorators import login_required
 
 
 class InviteView(FormView):
@@ -25,6 +23,7 @@ class InviteView(FormView):
 
         return super(InviteView, self).form_valid(form)
 
+
 class NotBetaView(TemplateView):
     """
     Display a message to the user after the invite request is completed
@@ -51,12 +50,11 @@ class InvalidView(TemplateView):
 
 class InviteSentView(TemplateView):
     """
-    Display a message to the user after sending out invitations to other people.
+    Display a message to the user after sending out invitations to people.
     """
     template_name = 'hunger/invite_sent.html'
 
 
-@login_required
 def verify_invite(request, code):
     """Verify new invitee by storing invite code for middleware to validate."""
     response = redirect(setting('HUNGER_VERIFIED_REDIRECT'))
